'use strict';

const service = require('../../index');

const registerResources = () => {
  const onSignalMQ = () => new Promise((resolve) => {
    // simulate cleanup time of 1 second
    setTimeout(() => {
      resolve(true);
    }, 1000);
  });

  const onSignalRest = () => new Promise((resolve) => {
    // simulate cleanup time of 2 seconds
    setTimeout(() => {
      resolve(true);
    }, 2000);
  });

  const onSignalDB = () => new Promise((resolve) => {
    // simulate cleanup time of 1 second
    setTimeout(() => {
      resolve({ message: 'DB closed' });
    }, 1000);
  });

  service.init({ timeout: 1000 });
  service.registerResource('db', { onSignal: onSignalDB }, 'last');
  service.registerResource('mq', { onSignal: onSignalMQ });
  service.registerResource('rest', { onSignal: onSignalRest });
};

const aSignal = () => new Promise((resolve) => {
  resolve(true);
});

const resourceStatus = [
  {
    name: 'mq',
    status: 'Running',
    signal: aSignal,
    order: 'general'
  },
  {
    name: 'rest',
    status: 'Running',
    signal: aSignal,
    order: 'general'
  },
  {
    name: 'db',
    status: 'Running',
    signal: aSignal,
    order: 'last'
  }
];

const runSigterm = () => {
  service.onSigterm();
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(true);
    }, 5000);
  });
};

module.exports = { registerResources, runSigterm, resourceStatus };
